@@ -1,10 +1,7 @@
-import {browserUpload, browserDownload}  from '../utils/browser';
 import {
   NEW_PROJECT,
   LOAD_PROJECT,
   SAVE_PROJECT,
-  LOAD_PROJECT_FROM_FILE,
-  SAVE_PROJECT_TO_FILE,
   OPEN_CATALOG,
   SELECT_TOOL_EDIT,
   UNSELECT_ALL,
@@ -13,15 +10,14 @@ import {
   UNDO,
   ROLLBACK,
   OPEN_PROJECT_CONFIGURATOR,
-  SET_PROJECT_PROPERTIES
+  SET_PROJECT_PROPERTIES,
+  INIT_CATALOG
 } from '../constants';
 
-export function loadProject(data) {
-  return (dispatch, getState, {catalog}) => {
-    dispatch({
-      type: LOAD_PROJECT,
-      data, catalog
-    });
+export function loadProject(sceneJSON) {
+  return {
+    type: LOAD_PROJECT,
+    sceneJSON
   }
 }
 
@@ -37,37 +33,9 @@ export function saveProject() {
   }
 }
 
-export function loadProjectFromFile() {
-  return function (dispatch, getState) {
-
-    dispatch({type: LOAD_PROJECT_FROM_FILE});
-
-    var upload = browserUpload();
-    upload.then((data) => {
-      dispatch(loadProject(JSON.parse(data)));
-    });
-  };
-}
-
-export function saveProjectToFile() {
-  return function (dispatch, getState) {
-
-    dispatch({type: SAVE_PROJECT_TO_FILE});
-
-    var state = getState();
-    let scene = state.get('scene').toJS();
-
-    browserDownload(scene);
-    dispatch(saveProject());
-  };
-}
-
 export function openCatalog() {
-  return (dispatch, getState, {catalog}) => {
-    dispatch({
-      type: OPEN_CATALOG,
-      catalog
-    });
+  return {
+    type: OPEN_CATALOG
   }
 }
 
@@ -92,11 +60,8 @@ export function setProperties(properties) {
 }
 
 export function remove() {
-  return (dispatch, getState, {catalog}) => {
-    dispatch({
-      type: REMOVE,
-      catalog
-    })
+  return {
+    type: REMOVE
   }
 }
 
@@ -124,3 +89,10 @@ export function setProjectProperties(properties) {
     properties
   }
 }
+
+export function initCatalog(catalog) {
+  return {
+    type: INIT_CATALOG,
+    catalog
+  }
+}
